/*******************************************************************************
  Main Source File

  Company:
    Microchip Technology Inc.

  File Name:
    main.c

  Summary:
    This file contains the "main" function for a project.

  Description:
    This file contains the "main" function for a project.  The
    "main" function calls the "SYS_Initialize" function to initialize the state
    machines of all modules in the system
 *******************************************************************************/

// *****************************************************************************
// *****************************************************************************
// Section: Included Files
// *****************************************************************************
// *****************************************************************************

#include <stddef.h>                     // Defines NULL
#include <stdbool.h>                    // Defines true
#include <stdlib.h>                     // Defines EXIT_FAILURE
#include <stdio.h>
#include <string.h>
#include "definitions.h"                // SYS function prototypes

#define MCP9800_Addr    0x4d 

static volatile bool    isRTCTimerExpired = false;
static volatile bool    isUSARTTxComplete = false;
static uint8_t          uartTxBuffer[30] = {0};
static volatile bool    bIsI2C_DONE = false ;
static unsigned char    I2C_ReadData[4];
static unsigned char    I2C_WriteData[4];

static void rtcEventHandler (RTC_TIMER32_INT_MASK intCause, uintptr_t context)
{
    if (intCause & RTC_TIMER32_INT_MASK_COMPARE_MATCH)
    {
        /* RTC timer compare match. Here -----> Step #5 */
        isRTCTimerExpired = true;
    }
}

static void usartTxHandler( uintptr_t context )
{
    isUSARTTxComplete = true;
}

static void i2cHandler(uintptr_t context)
{
    if(SERCOM2_I2C_ErrorGet() == SERCOM_I2C_ERROR_NONE)
    {
         bIsI2C_DONE = true ;
    }
    else
    {
        //Error occurred during transfer.
    }
}



// *****************************************************************************
// *****************************************************************************
// Section: Main Entry Point
// *****************************************************************************
// *****************************************************************************

int main ( void )
{
    /* Initialize all modules */
    SYS_Initialize ( NULL );
    
    SERCOM0_USART_WriteCallbackRegister(usartTxHandler, 0);
    SERCOM2_I2C_CallbackRegister(i2cHandler, (uintptr_t)NULL);
    RTC_Timer32CallbackRegister(rtcEventHandler, 0);
    RTC_Timer32Start();

    while ( true )
    {
        bool status;
        /* Maintain state machines of all polled MPLAB Harmony modules. */
        SYS_Tasks ( );
        
        if (isRTCTimerExpired == true)
        {
            isRTCTimerExpired = false;           
            LED1_Toggle();
            
                I2C_WriteData[0] = 0 ;          // Read Point 0 : Temperature !
                status = SERCOM2_I2C_WriteRead( MCP9800_Addr, I2C_WriteData, 1, I2C_ReadData, 2 );
                if (status == false)
                {                /* Handle error condition */
                }      
                
            sprintf((char*)uartTxBuffer, "Current Temperature %d \r\n", I2C_ReadData[0]);
            status = SERCOM0_USART_Write(uartTxBuffer, strlen((const char*)uartTxBuffer));
            if (status == false)
            {                /* Handle error condition */
            }
        }
  
    }

    /* Execution should not come here during normal operation */

    return ( EXIT_FAILURE );
}


/*******************************************************************************
 End of File
*/